@@ -41,6 +41,8 @@ public class NetworkTO {
     protected String ip6address;
     protected String ip6gateway;
     protected String ip6cidr;
+    protected String ip6Dns1;
+    protected String ip6Dns2;
 
     public NetworkTO() {
     }
@@ -221,4 +223,12 @@ public class NetworkTO {
     public boolean isSecurityGroupEnabled() {
         return this.isSecurityGroupEnabled;
     }
+
+    public void setIp6Dns1(String ip6Dns1) {
+        this.ip6Dns1 = ip6Dns1;
+    }
+
+    public void setIp6Dns2(String ip6Dns2) {
+        this.ip6Dns2 = ip6Dns2;
+    }
 }
