@@ -40,7 +40,6 @@ import com.cloud.utils.exception.CloudRuntimeException;
 requestHasSensitiveInfo = false, responseHasSensitiveInfo = false, since = "4.16.0")
 public class UpdateBackupOfferingCmd extends BaseCmd {
     private static final Logger LOGGER = Logger.getLogger(UpdateBackupOfferingCmd.class.getName());
-    private static final String APINAME = "updateBackupOffering";
 
     @Inject
     private BackupManager backupManager;
@@ -106,11 +105,6 @@ public class UpdateBackupOfferingCmd extends BaseCmd {
         }
     }
 
-    @Override
-    public String getCommandName() {
-        return APINAME.toLowerCase() + BaseCmd.RESPONSE_SUFFIX;
-    }
-
     @Override
     public long getEntityOwnerId() {
         return Account.ACCOUNT_ID_SYSTEM;
@@ -125,4 +119,4 @@ public class UpdateBackupOfferingCmd extends BaseCmd {
     public ApiCommandResourceType getApiResourceType() {
         return ApiCommandResourceType.BackupOffering;
     }
-}
\ No newline at end of file
+}
