@@ -36,7 +36,6 @@ import com.cloud.user.Account;
 public class UpdateClusterCmd extends BaseCmd {
     public static final Logger s_logger = Logger.getLogger(AddClusterCmd.class.getName());
 
-    private static final String s_name = "updateclusterresponse";
 
     @Parameter(name = ApiConstants.ID, type = CommandType.UUID, entityType = ClusterResponse.class, required = true, description = "the ID of the Cluster")
     private Long id;
@@ -72,11 +71,6 @@ public class UpdateClusterCmd extends BaseCmd {
         return hypervisor;
     }
 
-    @Override
-    public String getCommandName() {
-        return s_name;
-    }
-
     public String getClusterType() {
         return clusterType;
     }
