@@ -37,7 +37,6 @@ import com.cloud.user.Account;
 public class RemoveGuestOsMappingCmd extends BaseAsyncCmd {
 
     public static final Logger s_logger = Logger.getLogger(RemoveGuestOsMappingCmd.class.getName());
-    private static final String s_name = "removeguestosmappingresponse";
 
     /////////////////////////////////////////////////////
     //////////////// API parameters /////////////////////
@@ -58,11 +57,6 @@ public class RemoveGuestOsMappingCmd extends BaseAsyncCmd {
     /////////////// API Implementation///////////////////
     /////////////////////////////////////////////////////
 
-    @Override
-    public String getCommandName() {
-        return s_name;
-    }
-
     @Override
     public long getEntityOwnerId() {
         return Account.ACCOUNT_ID_SYSTEM;
