@@ -37,7 +37,6 @@ import com.cloud.user.Account;
 public class ReleaseHostReservationCmd extends BaseAsyncCmd {
     public static final Logger s_logger = Logger.getLogger(ReleaseHostReservationCmd.class.getName());
 
-    private static final String s_name = "releasehostreservationresponse";
 
     /////////////////////////////////////////////////////
     //////////////// API parameters /////////////////////
@@ -58,11 +57,6 @@ public class ReleaseHostReservationCmd extends BaseAsyncCmd {
     /////////////// API Implementation///////////////////
     /////////////////////////////////////////////////////
 
-    @Override
-    public String getCommandName() {
-        return s_name;
-    }
-
     @Override
     public long getEntityOwnerId() {
         Account account = CallContext.current().getCallingAccount();
