@@ -35,7 +35,6 @@ import com.cloud.user.Account;
 public class DeletePodCmd extends BaseCmd {
     public static final Logger s_logger = Logger.getLogger(DeletePodCmd.class.getName());
 
-    private static final String s_name = "deletepodresponse";
 
     /////////////////////////////////////////////////////
     //////////////// API parameters /////////////////////
@@ -56,11 +55,6 @@ public class DeletePodCmd extends BaseCmd {
     /////////////// API Implementation///////////////////
     /////////////////////////////////////////////////////
 
-    @Override
-    public String getCommandName() {
-        return s_name;
-    }
-
     @Override
     public long getEntityOwnerId() {
         return Account.ACCOUNT_ID_SYSTEM;
