@@ -39,7 +39,6 @@ import com.cloud.user.Account;
         requestHasSensitiveInfo = false, responseHasSensitiveInfo = false)
 public class DeleteAutoScalePolicyCmd extends BaseAsyncCmd {
     public static final Logger s_logger = Logger.getLogger(DeleteAutoScalePolicyCmd.class.getName());
-    private static final String s_name = "deleteautoscalepolicyresponse";
     // ///////////////////////////////////////////////////
     // ////////////// API parameters /////////////////////
     // ///////////////////////////////////////////////////
@@ -64,11 +63,6 @@ public class DeleteAutoScalePolicyCmd extends BaseAsyncCmd {
     // ///////////// API Implementation///////////////////
     // ///////////////////////////////////////////////////
 
-    @Override
-    public String getCommandName() {
-        return s_name;
-    }
-
     @Override
     public long getEntityOwnerId() {
         AutoScalePolicy autoScalePolicy = _entityMgr.findById(AutoScalePolicy.class, getId());
