@@ -41,7 +41,6 @@ import com.cloud.utils.exception.CloudRuntimeException;
 public class ListSslCertsCmd extends BaseCmd {
     public static final Logger s_logger = Logger.getLogger(ListSslCertsCmd.class.getName());
 
-    private static final String s_name = "listsslcertsresponse";
 
     @Inject
     CertService _certService;
@@ -102,11 +101,6 @@ public class ListSslCertsCmd extends BaseCmd {
         }
     }
 
-    @Override
-    public String getCommandName() {
-        return s_name;
-    }
-
     @Override
     public long getEntityOwnerId() {
         return CallContext.current().getCallingAccount().getId();
