@@ -35,7 +35,6 @@ import com.cloud.user.SSHKeyPair;
         requestHasSensitiveInfo = false, responseHasSensitiveInfo = false)
 public class DeleteSSHKeyPairCmd extends BaseCmd {
     public static final Logger s_logger = Logger.getLogger(DeleteSSHKeyPairCmd.class.getName());
-    private static final String s_name = "deletesshkeypairresponse";
 
     /////////////////////////////////////////////////////
     //////////////// API parameters /////////////////////
@@ -85,11 +84,6 @@ public class DeleteSSHKeyPairCmd extends BaseCmd {
         setResponseObject(response);
     }
 
-    @Override
-    public String getCommandName() {
-        return s_name;
-    }
-
     @Override
     public long getEntityOwnerId() {
         Account account = CallContext.current().getCallingAccount();
