@@ -38,7 +38,6 @@ import com.cloud.network.Site2SiteCustomerGateway;
 public class UpdateVpnCustomerGatewayCmd extends BaseAsyncCmd {
     public static final Logger s_logger = Logger.getLogger(UpdateVpnCustomerGatewayCmd.class.getName());
 
-    private static final String s_name = "updatevpncustomergatewayresponse";
 
     /////////////////////////////////////////////////////
     //////////////// API parameters /////////////////////
@@ -162,11 +161,6 @@ public class UpdateVpnCustomerGatewayCmd extends BaseAsyncCmd {
     /////////////// API Implementation///////////////////
     /////////////////////////////////////////////////////
 
-    @Override
-    public String getCommandName() {
-        return s_name;
-    }
-
     @Override
     public long getEntityOwnerId() {
         Long accountId = _accountService.finalyzeAccountId(accountName, domainId, null, true);
