@@ -163,6 +163,10 @@ public class NetworkResponse extends BaseResponseWithAssociatedNetwork implement
     @Param(description = "the domain name of the network owner")
     private String domain;
 
+    @SerializedName(ApiConstants.DOMAIN_PATH)
+    @Param(description = "path of the Domain the network belongs to", since = "4.19.0.0")
+    private String domainPath;
+
     @SerializedName("isdefault")
     @Param(description = "true if network is default, false otherwise")
     private Boolean isDefault;
@@ -420,6 +424,10 @@ public class NetworkResponse extends BaseResponseWithAssociatedNetwork implement
         this.domain = domain;
     }
 
+    public void setDomainPath(String domainPath) {
+        this.domainPath = domainPath;
+    }
+
     public void setNetworkOfferingAvailability(String networkOfferingAvailability) {
         this.networkOfferingAvailability = networkOfferingAvailability;
     }
