@@ -97,10 +97,18 @@ public class StoragePoolResponse extends BaseResponseWithAnnotations {
     @Param(description = "total min IOPS currently in use by volumes")
     private Long allocatedIops;
 
+    @SerializedName(ApiConstants.STORAGE_CUSTOM_STATS)
+    @Param(description = "the storage pool custom stats", since = "4.18.1")
+    private Map<String, String> customStats;
+
     @SerializedName("tags")
     @Param(description = "the tags for the storage pool")
     private String tags;
 
+    @SerializedName(ApiConstants.NFS_MOUNT_OPTIONS)
+    @Param(description = "the nfs mount options for the storage pool", since = "4.19.1")
+    private String nfsMountOpts;
+
     @SerializedName(ApiConstants.IS_TAG_A_RULE)
     @Param(description = ApiConstants.PARAMETER_DESCRIPTION_IS_TAG_A_RULE)
     private Boolean isTagARule;
@@ -300,6 +308,14 @@ public class StoragePoolResponse extends BaseResponseWithAnnotations {
        this.allocatedIops = allocatedIops;
     }
 
+    public Map<String, String> getCustomStats() {
+        return customStats;
+    }
+
+    public void setCustomStats(Map<String, String> customStats) {
+        this.customStats = customStats;
+    }
+
     public String getTags() {
         return tags;
     }
@@ -347,4 +363,12 @@ public class StoragePoolResponse extends BaseResponseWithAnnotations {
     public void setProvider(String provider) {
         this.provider = provider;
     }
+
+    public String getNfsMountOpts() {
+        return nfsMountOpts;
+    }
+
+    public void setNfsMountOpts(String nfsMountOpts) {
+        this.nfsMountOpts = nfsMountOpts;
+    }
 }
