@@ -22,10 +22,17 @@ import com.cloud.network.as.AutoScaleVmGroupVmMapVO;
 import com.cloud.utils.db.GenericDao;
 
 public interface AutoScaleVmGroupVmMapDao extends GenericDao<AutoScaleVmGroupVmMapVO, Long> {
+    int countAvailableVmsByGroup(long vmGroupId);
+
     public Integer countByGroup(long vmGroupId);
 
     public List<AutoScaleVmGroupVmMapVO> listByGroup(long vmGroupId);
 
+    public List<AutoScaleVmGroupVmMapVO> listByVm(long vmId);
+
     public int remove(long vmGroupId, long vmId);
 
+    public boolean removeByVm(long vmId);
+
+    public boolean removeByGroup(long vmGroupId);
 }
