@@ -31,12 +31,13 @@ import java.util.stream.Collectors;
 
 import javax.inject.Inject;
 
+import org.apache.cloudstack.api.ApiCommandResourceType;
 import org.apache.cloudstack.api.ApiConstants;
 import org.apache.cloudstack.api.BaseCmd;
 import org.apache.cloudstack.api.command.user.firewall.CreateFirewallRuleCmd;
 import org.apache.cloudstack.api.command.user.network.CreateNetworkACLCmd;
-import org.apache.cloudstack.api.command.user.vm.StartVMCmd;
 import org.apache.cloudstack.api.command.user.volume.ResizeVolumeCmd;
+import org.apache.cloudstack.context.CallContext;
 import org.apache.commons.codec.binary.Base64;
 import org.apache.commons.collections.CollectionUtils;
 import org.apache.commons.lang3.StringUtils;
@@ -321,18 +322,19 @@ public class KubernetesClusterResourceModifierActionWorker extends KubernetesClu
     }
 
     protected void startKubernetesVM(final UserVm vm) throws ManagementServerException {
+        CallContext vmContext = null;
+        if (!ApiCommandResourceType.VirtualMachine.equals(CallContext.current().getEventResourceType())); {
+            vmContext = CallContext.register(CallContext.current(), ApiCommandResourceType.VirtualMachine);
+            vmContext.setEventResourceId(vm.getId());
+        }
         try {
-            StartVMCmd startVm = new StartVMCmd();
-            startVm = ComponentContext.inject(startVm);
-            Field f = startVm.getClass().getDeclaredField("id");
-            f.setAccessible(true);
-            f.set(startVm, vm.getId());
-            itMgr.advanceStart(vm.getUuid(), null, null);
-            if (LOGGER.isInfoEnabled()) {
-                LOGGER.info(String.format("Started VM : %s in the Kubernetes cluster : %s", vm.getDisplayName(), kubernetesCluster.getName()));
-            }
-        } catch (IllegalAccessException | NoSuchFieldException | OperationTimedoutException | ResourceUnavailableException | InsufficientCapacityException ex) {
+            userVmManager.startVirtualMachine(vm);
+        } catch (OperationTimedoutException | ResourceUnavailableException | InsufficientCapacityException ex) {
             throw new ManagementServerException(String.format("Failed to start VM in the Kubernetes cluster : %s", kubernetesCluster.getName()), ex);
+        } finally {
+            if (vmContext != null) {
+                CallContext.unregister();
+            }
         }
 
         UserVm startVm = userVmDao.findById(vm.getId());
@@ -345,19 +347,25 @@ public class KubernetesClusterResourceModifierActionWorker extends KubernetesClu
             ResourceUnavailableException, InsufficientCapacityException {
         List<UserVm> nodes = new ArrayList<>();
         for (int i = offset + 1; i <= nodeCount; i++) {
-            UserVm vm = createKubernetesNode(publicIpAddress);
-            addKubernetesClusterVm(kubernetesCluster.getId(), vm.getId(), false);
-            if (kubernetesCluster.getNodeRootDiskSize() > 0) {
-                resizeNodeVolume(vm);
-            }
-            startKubernetesVM(vm);
-            vm = userVmDao.findById(vm.getId());
-            if (vm == null) {
-                throw new ManagementServerException(String.format("Failed to provision worker VM for Kubernetes cluster : %s" , kubernetesCluster.getName()));
-            }
-            nodes.add(vm);
-            if (LOGGER.isInfoEnabled()) {
-                LOGGER.info(String.format("Provisioned node VM : %s in to the Kubernetes cluster : %s", vm.getDisplayName(), kubernetesCluster.getName()));
+            CallContext vmContext = CallContext.register(CallContext.current(), ApiCommandResourceType.VirtualMachine);
+            try {
+                UserVm vm = createKubernetesNode(publicIpAddress);
+                vmContext.setEventResourceId(vm.getId());
+                addKubernetesClusterVm(kubernetesCluster.getId(), vm.getId(), false);
+                if (kubernetesCluster.getNodeRootDiskSize() > 0) {
+                    resizeNodeVolume(vm);
+                }
+                startKubernetesVM(vm);
+                vm = userVmDao.findById(vm.getId());
+                if (vm == null) {
+                    throw new ManagementServerException(String.format("Failed to provision worker VM for Kubernetes cluster : %s", kubernetesCluster.getName()));
+                }
+                nodes.add(vm);
+                if (LOGGER.isInfoEnabled()) {
+                    LOGGER.info(String.format("Provisioned node VM : %s in to the Kubernetes cluster : %s", vm.getDisplayName(), kubernetesCluster.getName()));
+                }
+            } finally {
+                CallContext.unregister();
             }
         }
         return nodes;
@@ -628,6 +636,7 @@ public class KubernetesClusterResourceModifierActionWorker extends KubernetesClu
 
     protected void createFirewallRules(IpAddress publicIp, List<Long> clusterVMIds, boolean apiRule) throws ManagementServerException {
         // Firewall rule for SSH access on each node VM
+        CallContext.register(CallContext.current(), null);
         try {
             int endPort = CLUSTER_NODES_DEFAULT_START_SSH_PORT + clusterVMIds.size() - 1;
             provisionFirewallRules(publicIp, owner, CLUSTER_NODES_DEFAULT_START_SSH_PORT, endPort);
@@ -636,11 +645,14 @@ public class KubernetesClusterResourceModifierActionWorker extends KubernetesClu
             }
         } catch (NoSuchFieldException | IllegalAccessException | ResourceUnavailableException | NetworkRuleConflictException e) {
             throw new ManagementServerException(String.format("Failed to provision firewall rules for SSH access for the Kubernetes cluster : %s", kubernetesCluster.getName()), e);
+        } finally {
+            CallContext.unregister();
         }
         if (!apiRule) {
             return;
         }
         // Firewall rule for API access for control node VMs
+        CallContext.register(CallContext.current(), null);
         try {
             provisionFirewallRules(publicIp, owner, CLUSTER_API_PORT, CLUSTER_API_PORT);
             if (LOGGER.isInfoEnabled()) {
@@ -649,6 +661,8 @@ public class KubernetesClusterResourceModifierActionWorker extends KubernetesClu
             }
         } catch (NoSuchFieldException | IllegalAccessException | ResourceUnavailableException | NetworkRuleConflictException e) {
             throw new ManagementServerException(String.format("Failed to provision firewall rules for API access for the Kubernetes cluster : %s", kubernetesCluster.getName()), e);
+        } finally {
+            CallContext.unregister();
         }
     }
 
@@ -689,6 +703,7 @@ public class KubernetesClusterResourceModifierActionWorker extends KubernetesClu
             return;
         }
         // ACL rule for API access for control node VMs
+        CallContext.register(CallContext.current(), null);
         try {
             provisionVpcTierAllowPortACLRule(network, CLUSTER_API_PORT, CLUSTER_API_PORT);
             if (LOGGER.isInfoEnabled()) {
@@ -697,7 +712,10 @@ public class KubernetesClusterResourceModifierActionWorker extends KubernetesClu
             }
         } catch (NoSuchFieldException | IllegalAccessException | ResourceUnavailableException | InvalidParameterValueException | PermissionDeniedException e) {
             throw new ManagementServerException(String.format("Failed to provision firewall rules for API access for the Kubernetes cluster : %s", kubernetesCluster.getName()), e);
+        } finally {
+            CallContext.unregister();
         }
+        CallContext.register(CallContext.current(), null);
         try {
             provisionVpcTierAllowPortACLRule(network, DEFAULT_SSH_PORT, DEFAULT_SSH_PORT);
             if (LOGGER.isInfoEnabled()) {
@@ -706,6 +724,8 @@ public class KubernetesClusterResourceModifierActionWorker extends KubernetesClu
             }
         } catch (NoSuchFieldException | IllegalAccessException | ResourceUnavailableException | InvalidParameterValueException | PermissionDeniedException e) {
             throw new ManagementServerException(String.format("Failed to provision firewall rules for API access for the Kubernetes cluster : %s", kubernetesCluster.getName()), e);
+        } finally {
+            CallContext.unregister();
         }
     }
 
