@@ -35,14 +35,13 @@ import com.cloud.exception.ConcurrentOperationException;
 import com.cloud.kubernetes.version.KubernetesVersionService;
 import org.apache.commons.lang3.StringUtils;
 
-@APICommand(name = ListKubernetesSupportedVersionsCmd.APINAME,
+@APICommand(name = "listKubernetesSupportedVersions",
         description = "Lists supported Kubernetes version",
         responseObject = KubernetesSupportedVersionResponse.class,
         responseView = ResponseObject.ResponseView.Restricted,
         authorized = {RoleType.Admin, RoleType.ResourceAdmin, RoleType.DomainAdmin, RoleType.User})
 public class ListKubernetesSupportedVersionsCmd extends BaseListCmd {
     public static final Logger LOGGER = Logger.getLogger(ListKubernetesSupportedVersionsCmd.class.getName());
-    public static final String APINAME = "listKubernetesSupportedVersions";
 
     @Inject
     private KubernetesVersionService kubernetesVersionService;
@@ -92,11 +91,6 @@ public class ListKubernetesSupportedVersionsCmd extends BaseListCmd {
         return minimumKubernetesVersionId;
     }
 
-    @Override
-    public String getCommandName() {
-        return APINAME.toLowerCase() + "response";
-    }
-
     /////////////////////////////////////////////////////
     /////////////// API Implementation///////////////////
     /////////////////////////////////////////////////////
