@@ -248,7 +248,8 @@ public class Site2SiteVpnManagerImpl extends ManagerBase implements Site2SiteVpn
 
         Site2SiteCustomerGatewayVO gw =
             new Site2SiteCustomerGatewayVO(name, accountId, owner.getDomainId(), gatewayIp, peerCidrList, ipsecPsk, ikePolicy, espPolicy, ikeLifetime, espLifetime, dpd, encap, splitConnections, ikeVersion);
-        _customerGatewayDao.persist(gw);
+        gw = _customerGatewayDao.persist(gw);
+        CallContext.current().putContextParameter(Site2SiteCustomerGateway.class, gw.getUuid());
         return gw;
     }
 
@@ -369,6 +370,11 @@ public class Site2SiteVpnManagerImpl extends ManagerBase implements Site2SiteVpn
         return _vpnGatewayDao.findById(vpnGatewayId);
     }
 
+    @Override
+    public Site2SiteCustomerGateway getCustomerGateway(Long customerGatewayId) {
+        return _customerGatewayDao.findById(customerGatewayId);
+    }
+
     @Override
     @ActionEvent(eventType = EventTypes.EVENT_S2S_VPN_CUSTOMER_GATEWAY_DELETE, eventDescription = "deleting s2s vpn customer gateway", create = true)
     public boolean deleteCustomerGateway(DeleteVpnCustomerGatewayCmd cmd) {
