@@ -71,6 +71,8 @@ public class ConsoleProxyServlet extends HttpServlet {
     private static final int DEFAULT_THUMBNAIL_WIDTH = 144;
     private static final int DEFAULT_THUMBNAIL_HEIGHT = 110;
 
+    private static final String SANITIZATION_REGEX = "[\n\r]";
+
     @Inject
     AccountManager _accountMgr;
     @Inject
@@ -154,7 +156,13 @@ public class ConsoleProxyServlet extends HttpServlet {
 
             String cmd = req.getParameter("cmd");
             if (cmd == null || !isValidCmd(cmd)) {
-                s_logger.debug("invalid console servlet command: " + cmd);
+                if (cmd != null) {
+                    cmd = cmd.replaceAll(SANITIZATION_REGEX, "_");
+                    s_logger.debug(String.format("invalid console servlet command [%s].", cmd));
+                } else {
+                    s_logger.debug("Null console servlet command.");
+                }
+
                 sendResponse(resp, "");
                 return;
             }
@@ -162,7 +170,13 @@ public class ConsoleProxyServlet extends HttpServlet {
             String vmIdString = req.getParameter("vm");
             VirtualMachine vm = _entityMgr.findByUuid(VirtualMachine.class, vmIdString);
             if (vm == null) {
-                s_logger.info("invalid console servlet command parameter: " + vmIdString);
+                if (vmIdString != null) {
+                    vmIdString = vmIdString.replaceAll(SANITIZATION_REGEX, "_");
+                    s_logger.info(String.format("invalid console servlet command vm parameter[%s].", vmIdString));
+                } else {
+                    s_logger.info("Null console servlet command VM parameter.");
+                }
+
                 sendResponse(resp, "");
                 return;
             }
@@ -262,7 +276,13 @@ public class ConsoleProxyServlet extends HttpServlet {
 
         String sid = req.getParameter("sid");
         if (sid == null || !sid.equals(vm.getVncPassword())) {
-            s_logger.warn("sid " + sid + " in url does not match stored sid.");
+            if(sid != null) {
+                sid = sid.replaceAll(SANITIZATION_REGEX, "_");
+                s_logger.warn(String.format("sid [%s] in url does not match stored sid.", sid));
+            } else {
+                s_logger.warn("Null sid in URL.");
+            }
+
             sendResponse(resp, "failed");
             return;
         }
