@@ -17,16 +17,32 @@
 
 package com.cloud.user;
 
-import java.util.ArrayList;
-import java.util.Collections;
-import java.util.List;
-import java.util.UUID;
-
+import com.cloud.api.query.dao.DiskOfferingJoinDao;
 import com.cloud.api.query.dao.NetworkOfferingJoinDao;
+import com.cloud.api.query.dao.ServiceOfferingJoinDao;
 import com.cloud.api.query.dao.VpcOfferingJoinDao;
+import com.cloud.configuration.ConfigurationManager;
+import com.cloud.configuration.Resource.ResourceOwnerType;
 import com.cloud.configuration.ResourceLimit;
+import com.cloud.configuration.dao.ResourceCountDao;
+import com.cloud.configuration.dao.ResourceLimitDao;
+import com.cloud.dc.DedicatedResourceVO;
+import com.cloud.dc.dao.DedicatedResourceDao;
+import com.cloud.domain.Domain;
+import com.cloud.domain.DomainVO;
+import com.cloud.domain.dao.DomainDao;
 import com.cloud.domain.dao.DomainDetailsDao;
+import com.cloud.exception.InvalidParameterValueException;
+import com.cloud.exception.PermissionDeniedException;
+import com.cloud.network.dao.NetworkDomainDao;
+import com.cloud.projects.ProjectManager;
+import com.cloud.projects.dao.ProjectDao;
+import com.cloud.user.dao.AccountDao;
 import com.cloud.utils.UuidUtils;
+import com.cloud.utils.db.Filter;
+import com.cloud.utils.db.GlobalLock;
+import com.cloud.utils.db.SearchCriteria;
+import com.cloud.utils.exception.CloudRuntimeException;
 import com.cloud.utils.net.NetUtils;
 import org.apache.cloudstack.annotation.dao.AnnotationDao;
 import org.apache.cloudstack.context.CallContext;
@@ -41,37 +57,18 @@ import org.junit.runner.RunWith;
 import org.mockito.InjectMocks;
 import org.mockito.Matchers;
 import org.mockito.Mock;
+import org.mockito.MockedStatic;
 import org.mockito.Mockito;
 import org.mockito.Spy;
+import org.mockito.junit.MockitoJUnitRunner;
 
-import com.cloud.api.query.dao.DiskOfferingJoinDao;
-import com.cloud.api.query.dao.ServiceOfferingJoinDao;
-import com.cloud.configuration.ConfigurationManager;
-import com.cloud.configuration.Resource.ResourceOwnerType;
-import com.cloud.configuration.dao.ResourceCountDao;
-import com.cloud.configuration.dao.ResourceLimitDao;
-import com.cloud.dc.DedicatedResourceVO;
-import com.cloud.dc.dao.DedicatedResourceDao;
-import com.cloud.domain.Domain;
-import com.cloud.domain.DomainVO;
-import com.cloud.domain.dao.DomainDao;
-import com.cloud.exception.InvalidParameterValueException;
-import com.cloud.exception.PermissionDeniedException;
-import com.cloud.network.dao.NetworkDomainDao;
-import com.cloud.projects.ProjectManager;
-import com.cloud.projects.dao.ProjectDao;
-import com.cloud.user.dao.AccountDao;
-import com.cloud.utils.db.Filter;
-import com.cloud.utils.db.GlobalLock;
-import com.cloud.utils.db.SearchCriteria;
-import com.cloud.utils.exception.CloudRuntimeException;
-import org.powermock.api.mockito.PowerMockito;
-import org.powermock.core.classloader.annotations.PowerMockIgnore;
-import org.powermock.core.classloader.annotations.PrepareForTest;
-import org.powermock.modules.junit4.PowerMockRunner;
+import java.util.ArrayList;
+import java.util.Collections;
+import java.util.List;
+import java.util.UUID;
 
-@PowerMockIgnore("javax.management.*")
-@RunWith(PowerMockRunner.class)
+
+@RunWith(MockitoJUnitRunner.class)
 public class DomainManagerImplTest {
     @Mock
     DomainDao domainDaoMock;
@@ -317,13 +314,13 @@ public class DomainManagerImplTest {
     }
 
     @Test
-    @PrepareForTest(NetUtils.class)
     public void validateNetworkDomainTestNullNetworkDomainDoesNotCallVerifyDomainName() {
-        PowerMockito.mockStatic(NetUtils.class);
-        PowerMockito.when(NetUtils.verifyDomainName(Mockito.anyString())).thenReturn(true);
-        domainManager.validateNetworkDomain(null);
-        PowerMockito.verifyStatic(NetUtils.class, Mockito.never());
-        NetUtils.verifyDomainName(Mockito.anyString());
+        try (MockedStatic<NetUtils> ignored = Mockito.mockStatic(NetUtils.class)) {
+            Mockito.when(NetUtils.verifyDomainName(Mockito.anyString())).thenReturn(true);
+            domainManager.validateNetworkDomain(null);
+            Mockito.verify(NetUtils.class, Mockito.never());
+            NetUtils.verifyDomainName(Mockito.anyString());
+        }
     }
 
     @Test (expected = InvalidParameterValueException.class)
@@ -386,29 +383,28 @@ public class DomainManagerImplTest {
     }
 
     @Test
-    @PrepareForTest(CallContext.class)
     public void createDomainTest(){
         Mockito.doNothing().when(domainManager).validateDomainNameAndNetworkDomain(Mockito.any(String.class), Mockito.any(Long.class), Mockito.any(String.class));
 
         DomainVO domainVoMock = Mockito.mock(DomainVO.class);
         Mockito.doReturn(domainVoMock).when(domainManager).createDomainVo("test",1L,2L,"netTest","uuidTest");
         Mockito.doReturn(domainVoMock).when(domainDaoMock).create(domainVoMock);
-        PowerMockito.mockStatic(CallContext.class);
-        CallContext callContextMock = Mockito.mock(CallContext.class);
-        PowerMockito.when(CallContext.current()).thenReturn(callContextMock);
+        try (MockedStatic<CallContext> ignored = Mockito.mockStatic(CallContext.class)) {
+            CallContext callContextMock = Mockito.mock(CallContext.class);
+            Mockito.when(CallContext.current()).thenReturn(callContextMock);
 
-        Domain actualDomain = domainManager.createDomain("test",1L,2L,"netTest","uuidTest");
+            Domain actualDomain = domainManager.createDomain("test", 1L, 2L, "netTest", "uuidTest");
 
-        Mockito.verify(domainManager).validateDomainNameAndNetworkDomain("test", 1L, "netTest");
-        Mockito.verify(domainManager).createDomainVo("test",1L,2L,"netTest","uuidTest");
+            Mockito.verify(domainManager).validateDomainNameAndNetworkDomain("test", 1L, "netTest");
+            Mockito.verify(domainManager).createDomainVo("test", 1L, 2L, "netTest", "uuidTest");
 
-        Mockito.verify(domainDaoMock).create(domainVoMock);
-        Mockito.verify(_resourceCountDao).createResourceCounts(domainVoMock.getId(), ResourceLimit.ResourceOwnerType.Domain);
-        PowerMockito.verifyStatic(CallContext.class);
-        CallContext.current();
-        Mockito.verify(callContextMock).putContextParameter(Domain.class, domainVoMock.getUuid());
-        Mockito.verify(_messageBus).publish("DomainManagerImpl", DomainManager.MESSAGE_ADD_DOMAIN_EVENT, PublishScope.LOCAL, domainVoMock.getId());
-        Assert.assertEquals(domainVoMock, actualDomain);
+            Mockito.verify(domainDaoMock).create(domainVoMock);
+            Mockito.verify(_resourceCountDao).createResourceCounts(domainVoMock.getId(), ResourceLimit.ResourceOwnerType.Domain);
+            CallContext.current();
+            Mockito.verify(callContextMock).putContextParameter(Domain.class, domainVoMock.getUuid());
+            Mockito.verify(_messageBus).publish("DomainManagerImpl", DomainManager.MESSAGE_ADD_DOMAIN_EVENT, PublishScope.LOCAL, domainVoMock.getId());
+            Assert.assertEquals(domainVoMock, actualDomain);
+        }
     }
 
 }
