@@ -98,7 +98,7 @@ function install_packages() {
   apt-key fingerprint 0EBFCD88
   add-apt-repository "deb [arch=amd64] https://download.docker.com/linux/debian $(lsb_release -cs) stable"
   apt-get update
-  ${apt_get} install docker-ce docker-ce-cli containerd.io
+  ${apt_get} install containerd.io
 
   apt_clean
 
