@@ -37,6 +37,7 @@ export default {
       icon: 'team-outlined',
       docHelp: 'adminguide/accounts.html#using-an-ldap-server-for-user-authentication',
       permission: ['listLdapConfigurations'],
+      searchFilters: ['domainid', 'hostname', 'port'],
       columns: ['hostname', 'port', 'domainid'],
       details: ['hostname', 'port', 'domainid'],
       actions: [
@@ -100,7 +101,25 @@ export default {
           label: 'label.edit',
           dataView: true,
           popup: true,
-          args: ['description', 'clientid', 'redirecturi', 'secretkey', 'enabled']
+          args: ['description', 'clientid', 'redirecturi', 'secretkey']
+        },
+        {
+          api: 'updateOauthProvider',
+          icon: 'play-circle-outlined',
+          label: 'label.enable.provider',
+          message: 'message.confirm.enable.provider',
+          dataView: true,
+          defaultArgs: { enabled: true },
+          show: (record) => { return record.enabled === false }
+        },
+        {
+          api: 'updateOauthProvider',
+          icon: 'pause-circle-outlined',
+          label: 'label.disable.provider',
+          message: 'message.confirm.disable.provider',
+          dataView: true,
+          defaultArgs: { enabled: false },
+          show: (record) => { return record.enabled === true }
         },
         {
           api: 'deleteOauthProvider',
@@ -118,6 +137,7 @@ export default {
       icon: 'database-outlined',
       docHelp: 'adminguide/hosts.html?highlight=Hypervisor%20capabilities#hypervisor-capabilities',
       permission: ['listHypervisorCapabilities'],
+      searchFilters: ['hypervisor'],
       columns: ['hypervisor', 'hypervisorversion', 'maxguestslimit', 'maxhostspercluster'],
       details: ['hypervisor', 'hypervisorversion', 'maxguestslimit', 'maxdatavolumeslimit', 'maxhostspercluster', 'securitygroupenabled', 'storagemotionenabled'],
       actions: [
