@@ -82,7 +82,7 @@ export default {
       }, {
         name: 'vnf.appliances',
         component: shallowRef(defineAsyncComponent(() => import('@/views/network/VnfAppliancesTab.vue'))),
-        show: () => { return 'deployVnfAppliance' in store.getters.apis }
+        show: () => { return 'listVnfAppliances' in store.getters.apis }
       }, {
         name: 'guest.ip.range',
         component: shallowRef(defineAsyncComponent(() => import('@/views/network/GuestIpRanges.vue'))),
@@ -337,7 +337,7 @@ export default {
       name: 'vnfapp',
       title: 'label.vnf.appliances',
       icon: 'gateway-outlined',
-      permission: ['listVirtualMachinesMetrics'],
+      permission: ['listVnfAppliances'],
       resourceType: 'UserVm',
       params: () => {
         return { details: 'servoff,tmpl,nics', isvnf: true }
@@ -748,6 +748,7 @@ export default {
       icon: 'environment-outlined',
       docHelp: 'adminguide/networking_and_traffic.html#reserving-public-ip-addresses-and-vlans-for-accounts',
       permission: ['listPublicIpAddresses'],
+      searchFilters: ['ipaddress', 'zoneid', 'account', 'domainid', 'vlanid', 'tags'],
       resourceType: 'PublicIpAddress',
       columns: () => {
         var fields = ['ipaddress', 'state', 'associatednetworkname', 'vpcname', 'virtualmachinename', 'allocated', 'account']
@@ -921,7 +922,6 @@ export default {
       name: 's2svpn',
       title: 'label.site.to.site.vpn',
       icon: 'lock-outlined',
-      hidden: true,
       permission: ['listVpnGateways'],
       columns: ['publicip', 'account', 'domain'],
       details: ['publicip', 'account', 'domain'],
@@ -1046,6 +1046,11 @@ export default {
         name: 'loadbalancerinstance',
         component: shallowRef(defineAsyncComponent(() => import('@/views/network/InternalLBAssignedVmTab.vue'))),
         show: () => true
+      }, {
+        name: 'events',
+        resourceType: 'LoadBalancerRule',
+        component: shallowRef(defineAsyncComponent(() => import('@/components/view/EventsTab.vue'))),
+        show: () => { return 'listEvents' in store.getters.apis }
       }],
       actions: [
         {
@@ -1162,6 +1167,12 @@ export default {
           name: 'details',
           component: shallowRef(defineAsyncComponent(() => import('@/components/view/DetailsTab.vue')))
         },
+        {
+          name: 'events',
+          resourceType: 'VpnCustomerGateway',
+          component: shallowRef(defineAsyncComponent(() => import('@/components/view/EventsTab.vue'))),
+          show: () => { return 'listEvents' in store.getters.apis }
+        },
         {
           name: 'comments',
           component: shallowRef(defineAsyncComponent(() => import('@/components/view/AnnotationsTab.vue')))
