@@ -15,17 +15,14 @@
 // specific language governing permissions and limitations
 // under the License.
 
-import Vue from 'vue'
-import Vuex from 'vuex'
+import { createStore } from 'vuex'
 
 import app from './modules/app'
 import user from './modules/user'
 import permission from './modules/permission'
 import getters from './getters'
 
-Vue.use(Vuex)
-
-export default new Vuex.Store({
+export default createStore({
   modules: {
     app,
     user,
