@@ -144,7 +144,12 @@ public class BaseMO {
     public int getCustomFieldKey(String morType, String fieldName) throws Exception {
         assert (morType != null);
 
-        CustomFieldsManagerMO cfmMo = new CustomFieldsManagerMO(_context, _context.getServiceContent().getCustomFieldsManager());
+        ManagedObjectReference cfmMor = _context.getServiceContent().getCustomFieldsManager();
+        if (cfmMor == null) {
+            return 0;
+        }
+
+        CustomFieldsManagerMO cfmMo = new CustomFieldsManagerMO(_context, cfmMor);
 
         return cfmMo.getCustomFieldKey(morType, fieldName);
     }
