@@ -35,6 +35,7 @@ import java.util.ArrayList;
 import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
+import java.util.concurrent.atomic.AtomicLong;
 
 import javax.net.ssl.HostnameVerifier;
 import javax.net.ssl.HttpsURLConnection;
@@ -469,7 +470,7 @@ public class VmwareContext {
         }
     }
 
-    public long downloadVmdkFile(String urlString, String localFileName, long totalBytesDownloaded, ActionDelegate<Long> progressUpdater) throws Exception {
+    public long downloadVmdkFile(String urlString, String localFileName, AtomicLong totalBytesDownloaded, ActionDelegate<Long> progressUpdater) throws Exception {
         HttpURLConnection conn = getRawHTTPConnection(urlString);
 
         String cookie = _vimClient.getServiceCookie();
@@ -495,10 +496,10 @@ public class VmwareContext {
             while ((len = in.read(buf)) > 0) {
                 out.write(buf, 0, len);
                 bytesWritten += len;
-                totalBytesDownloaded += len;
+                totalBytesDownloaded.addAndGet(len);
 
                 if (progressUpdater != null)
-                    progressUpdater.action(new Long(totalBytesDownloaded));
+                    progressUpdater.action(new Long(totalBytesDownloaded.get()));
             }
         } finally {
             if (in != null)
