@@ -807,8 +807,13 @@ public class VmwareHelper {
                 instance.setMemory(configSummary.getMemorySizeMB());
             }
 
-            ClusterMO clusterMo = new ClusterMO(hyperHost.getContext(), hyperHost.getHyperHostCluster());
-            instance.setClusterName(clusterMo.getName());
+            try {
+                ClusterMO clusterMo = new ClusterMO(hyperHost.getContext(), hyperHost.getHyperHostCluster());
+                instance.setClusterName(clusterMo.getName());
+            } catch (Exception e) {
+                s_logger.warn("Unable to get unmanaged instance cluster info, due to: " + e.getMessage());
+            }
+
             instance.setHostName(hyperHost.getHyperHostName());
 
             if (StringUtils.isEmpty(instance.getOperatingSystemId()) && configSummary != null) {
@@ -838,7 +843,7 @@ public class VmwareHelper {
             instance.setDisks(getUnmanageInstanceDisks(vmMo));
             instance.setNics(getUnmanageInstanceNics(hyperHost, vmMo));
         } catch (Exception e) {
-            s_logger.info("Unable to retrieve unmanaged instance info. " + e.getMessage());
+            s_logger.error("Unable to retrieve unmanaged instance info, due to: " + e.getMessage());
         }
         return instance;
     }
